# Generated by Django 6.0.1 on 2026-01-29 10:19

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="RequestLog",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("method", models.CharField(max_length=10)),
                ("url", models.TextField()),
                ("request_body", models.TextField(blank=True, default="")),
                ("response_status", models.IntegerField()),
                ("response_body", models.TextField(blank=True, default="")),
                ("start", models.DateTimeField()),
                ("end", models.DateTimeField()),
                (
                    "user",
                    models.ForeignKey(
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
        ),
    ]
